/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_hr extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "ADP", "ADP" },
            { "AED", "AED" },
            { "AFA", "AFA" },
            { "AFN", "AFN" },
            { "ALK", "ALK" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "AOK", "AOK" },
            { "AON", "AON" },
            { "AOR", "AOR" },
            { "ARA", "ARA" },
            { "ARL", "ARL" },
            { "ARM", "ARM" },
            { "ARP", "ARP" },
            { "ARS", "ARS" },
            { "ATS", "ATS" },
            { "AUD", "AUD" },
            { "AWG", "AWG" },
            { "AZM", "AZM" },
            { "AZN", "AZN" },
            { "BAD", "BAD" },
            { "BAM", "BAM" },
            { "BAN", "BAN" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BEC", "BEC" },
            { "BEF", "BEF" },
            { "BEL", "BEL" },
            { "BGL", "BGL" },
            { "BGM", "BGM" },
            { "BGN", "BGN" },
            { "BGO", "BGO" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BOL", "BOL" },
            { "BOP", "BOP" },
            { "BOV", "BOV" },
            { "BRB", "BRB" },
            { "BRC", "BRC" },
            { "BRE", "BRE" },
            { "BRL", "BRL" },
            { "BRN", "BRN" },
            { "BRR", "BRR" },
            { "BRZ", "BRZ" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BUK", "BUK" },
            { "BWP", "BWP" },
            { "BYB", "BYB" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CAD", "CAD" },
            { "CDF", "CDF" },
            { "CHE", "CHE" },
            { "CHF", "CHF" },
            { "CHW", "CHW" },
            { "CLE", "CLE" },
            { "CLF", "CLF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "CNX", "CNX" },
            { "CNY", "CNY" },
            { "COP", "COP" },
            { "COU", "COU" },
            { "CRC", "CRC" },
            { "CSD", "CSD" },
            { "CSK", "CSK" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CYP", "CYP" },
            { "CZK", "CZK" },
            { "DDM", "DDM" },
            { "DEM", "DEM" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "ECS", "ECS" },
            { "ECV", "ECV" },
            { "EEK", "EEK" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ESA", "ESA" },
            { "ESB", "ESB" },
            { "ESP", "ESP" },
            { "ETB", "ETB" },
            { "EUR", "EUR" },
            { "FIM", "FIM" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "FRF", "FRF" },
            { "GBP", "GBP" },
            { "GEK", "GEK" },
            { "GEL", "GEL" },
            { "GHC", "GHC" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GNS", "GNS" },
            { "GQE", "GQE" },
            { "GRD", "GRD" },
            { "GTQ", "GTQ" },
            { "GWE", "GWE" },
            { "GWP", "GWP" },
            { "GYD", "GYD" },
            { "HKD", "HKD" },
            { "HNL", "HNL" },
            { "HRD", "HRD" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IEP", "IEP" },
            { "ILP", "ILP" },
            { "ILR", "ILR" },
            { "ILS", "ILS" },
            { "INR", "INR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISJ", "ISJ" },
            { "ISK", "ISK" },
            { "ITL", "ITL" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "JPY", "JPY" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KRH", "KRH" },
            { "KRO", "KRO" },
            { "KRW", "KRW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LSL", "LSL" },
            { "LTL", "LTL" },
            { "LTT", "LTT" },
            { "LUC", "LUC" },
            { "LUF", "LUF" },
            { "LUL", "LUL" },
            { "LVL", "LVL" },
            { "LVR", "LVR" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MAF", "MAF" },
            { "MCF", "MCF" },
            { "MDC", "MDC" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MGF", "MGF" },
            { "MKD", "MKD" },
            { "MKN", "MKN" },
            { "MLF", "MLF" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MRU", "MRU" },
            { "MTL", "MTL" },
            { "MTP", "MTP" },
            { "MUR", "MUR" },
            { "MVP", "MVP" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MXN", "MXN" },
            { "MXP", "MXP" },
            { "MXV", "MXV" },
            { "MYR", "MYR" },
            { "MZE", "MZE" },
            { "MZM", "MZM" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIC", "NIC" },
            { "NIO", "NIO" },
            { "NLG", "NLG" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "NZD", "NZD" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEI", "PEI" },
            { "PEN", "PEN" },
            { "PES", "PES" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PLZ", "PLZ" },
            { "PTE", "PTE" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RHD", "RHD" },
            { "ROL", "ROL" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RUR", "RUR" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDD", "SDD" },
            { "SDG", "SDG" },
            { "SDP", "SDP" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SIT", "SIT" },
            { "SKK", "SKK" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SRG", "SRG" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SUR", "SUR" },
            { "SVC", "SVC" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "THB" },
            { "TJR", "TJR" },
            { "TJS", "TJS" },
            { "TMM", "TMM" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TPE", "TPE" },
            { "TRL", "TRL" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TWD", "TWD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UAK", "UAK" },
            { "UGS", "UGS" },
            { "UGX", "UGX" },
            { "USD", "USD" },
            { "USN", "USN" },
            { "USS", "USS" },
            { "UYI", "UYI" },
            { "UYP", "UYP" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEB", "VEB" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VND", "VND" },
            { "VNN", "VNN" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "XAG", "XAG" },
            { "XAU", "XAU" },
            { "XBA", "XBA" },
            { "XBB", "XBB" },
            { "XBC", "XBC" },
            { "XBD", "XBD" },
            { "XCD", "XCD" },
            { "XDR", "XDR" },
            { "XEU", "XEU" },
            { "XFO", "XFO" },
            { "XFU", "XFU" },
            { "XPD", "XPD" },
            { "XPF", "XPF" },
            { "XPT", "XPT" },
            { "XRE", "XRE" },
            { "XSU", "XSU" },
            { "XTS", "XTS" },
            { "XUA", "XUA" },
            { "XXX", "XXX" },
            { "YDD", "YDD" },
            { "YER", "YER" },
            { "YUD", "YUD" },
            { "YUM", "YUM" },
            { "YUN", "YUN" },
            { "YUR", "YUR" },
            { "ZAL", "ZAL" },
            { "ZAR", "ZAR" },
            { "ZMK", "ZMK" },
            { "ZMW", "ZMW" },
            { "ZRN", "ZRN" },
            { "ZRZ", "ZRZ" },
            { "ZWD", "ZWD" },
            { "ZWL", "ZWL" },
            { "ZWR", "ZWR" },
            { "adp", "andorska pezeta" },
            { "aed", "UAE dirham" },
            { "afa", "afganistanski afgani (1927.\u20132002.)" },
            { "afn", "afganistanski afgani" },
            { "alk", "stari albanski lek" },
            { "all", "albanski lek" },
            { "amd", "armenski dram" },
            { "ang", "nizozemskoantilski gulden" },
            { "aoa", "angolska kvanza" },
            { "aok", "angolska kvanza (1977.\u20131990.)" },
            { "aon", "angolska nova kvanza (1990.\u20132000.)" },
            { "aor", "angolska kvanza (1995.\u20131999.)" },
            { "ara", "argentinski austral" },
            { "arl", "argentinski pezo lej (1970.\u20131983.)" },
            { "arm", "argentinski pezo (1881.\u20131970.)" },
            { "arp", "argentinski pezo (1983.\u20131985.)" },
            { "ars", "argentinski pezo" },
            { "ats", "austrijski \u0161iling" },
            { "aud", "australski dolar" },
            { "awg", "arupski florin" },
            { "azm", "azerbajd\u017eanski manat (1993.\u20132006.)" },
            { "azn", "azerbajd\u017eanski manat" },
            { "bad", "bosansko-hercegova\u010dki dinar" },
            { "bam", "konvertibilna marka" },
            { "ban", "bosansko-hercegova\u010dki novi dinar" },
            { "bbd", "barbadoski dolar" },
            { "bdt", "banglade\u0161ka taka" },
            { "bec", "belgijski franak (konvertibilan)" },
            { "bef", "belgijski franak" },
            { "bel", "belgijski franak (financijski)" },
            { "bgl", "bugarski \u010dvrsti lev" },
            { "bgm", "bugarski socijalisti\u010dki lev" },
            { "bgn", "bugarski lev" },
            { "bgo", "stari bugarski lev" },
            { "bhd", "bahreinski dinar" },
            { "bif", "burundski franak" },
            { "bmd", "bermudski dolar" },
            { "bnd", "brunejski dolar" },
            { "bob", "bolivijski bolivijano" },
            { "bol", "stari bolivijski bolivijano" },
            { "bop", "bolivijski pezo" },
            { "bov", "bolivijski mvdol" },
            { "brb", "brazilski novi cruzeiro (1967.\u20131986.)" },
            { "brc", "brazilski cruzado" },
            { "bre", "brazilski cruzeiro (1990.\u20131993.)" },
            { "brl", "brazilski real" },
            { "brn", "brazilski novi cruzado" },
            { "brr", "brazilski cruzeiro" },
            { "bsd", "bahamski dolar" },
            { "btn", "butanski ngultrum" },
            { "buk", "burmanski kyat" },
            { "bwp", "bocvanska pula" },
            { "byb", "bjeloruska nova rublja (1994\u20131999)" },
            { "byn", "bjeloruski rubalj" },
            { "byr", "bjeloruska rublja (2000\u20132016)" },
            { "bzd", "belizeanski dolar" },
            { "cad", "kanadski dolar" },
            { "cdf", "kongoanski franak" },
            { "che", "WIR euro" },
            { "chf", "\u0161vicarski franak" },
            { "chw", "WIR franak" },
            { "cle", "\u010dileanski eskudo" },
            { "clf", "\u010dileanski unidades de fomentos" },
            { "clp", "\u010dileanski pezo" },
            { "cnh", "kineski juan (offshore)" },
            { "cnx", "kineski narodni dolar" },
            { "cny", "kineski yuan" },
            { "cop", "kolumbijski pezo" },
            { "cou", "unidad de valor real" },
            { "crc", "kostarikanski kolon" },
            { "csd", "stari srpski dinar" },
            { "csk", "\u010dehoslova\u010dka kruna" },
            { "cuc", "kubanski konvertibilni pezo" },
            { "cup", "kubanski pezo" },
            { "cve", "zelenortski eskudo" },
            { "cyp", "ciparska funta" },
            { "czk", "\u010de\u0161ka kruna" },
            { "ddm", "isto\u010dnonjema\u010dka marka" },
            { "dem", "njema\u010dka marka" },
            { "djf", "d\u017eibutski franak" },
            { "dkk", "danska kruna" },
            { "dop", "dominikanski pezo" },
            { "dzd", "al\u017eirski dinar" },
            { "ecs", "ekvatorska sukra" },
            { "ecv", "ekvatorski unidad de valor constante (UVC)" },
            { "eek", "estonska kruna" },
            { "egp", "egipatska funta" },
            { "ern", "eritrejska nakfa" },
            { "esa", "\u0161panjolska pezeta (A ra\u010dun)" },
            { "esb", "\u0161panjolska pezeta (konvertibilni ra\u010dun)" },
            { "esp", "\u0161panjolska pezeta" },
            { "etb", "etiopski bir" },
            { "eur", "euro" },
            { "fim", "finska marka" },
            { "fjd", "fid\u017eijski dolar" },
            { "fkp", "falklandska funta" },
            { "frf", "francuski franak" },
            { "gbp", "britanska funta" },
            { "gek", "gruzijski kupon larit" },
            { "gel", "gruzijski lari" },
            { "ghc", "ganski cedi (1979.\u20132007.)" },
            { "ghs", "ganski cedi" },
            { "gip", "gibraltarska funta" },
            { "gmd", "gambijski dalas" },
            { "gnf", "gvinejski franak" },
            { "gns", "gvinejski syli" },
            { "gqe", "ekvatorski gvinejski ekwele" },
            { "grd", "gr\u010dka drahma" },
            { "gtq", "gvatemalski kvecal" },
            { "gwe", "portugalski gvinejski eskudo" },
            { "gwp", "gvinejskobisauski pezo" },
            { "gyd", "gvajanski dolar" },
            { "hkd", "hongkon\u0161ki dolar" },
            { "hnl", "hondura\u0161ka lempira" },
            { "hrd", "hrvatski dinar" },
            { "hrk", "hrvatska kuna" },
            { "htg", "hai\u0107anski gourd" },
            { "huf", "ma\u0111arska forinta" },
            { "idr", "indonezijska rupija" },
            { "iep", "irska funta" },
            { "ilp", "izraelska funta" },
            { "ilr", "stari izraelski \u0161ekel" },
            { "ils", "novi izraelski \u0161ekel" },
            { "inr", "indijska rupija" },
            { "iqd", "ira\u010dki dinar" },
            { "irr", "iranski rijal" },
            { "isj", "stara islandska kruna" },
            { "isk", "islandska kruna" },
            { "itl", "talijanska lira" },
            { "jmd", "jamaj\u010danski dolar" },
            { "jod", "jordanski dinar" },
            { "jpy", "japanski jen" },
            { "kes", "kenijski \u0161iling" },
            { "kgs", "kirgiski som" },
            { "khr", "kambod\u017eanski rijal" },
            { "kmf", "komorski franak" },
            { "kpw", "sjevernokorejski won" },
            { "krh", "ju\u017enokorejski hvan" },
            { "kro", "stari ju\u017enokorejski von" },
            { "krw", "ju\u017enokorejski won" },
            { "kwd", "kuvajtski dinar" },
            { "kyd", "kajmanski dolar" },
            { "kzt", "kazahstanski tenge" },
            { "lak", "laoski kip" },
            { "lbp", "libanonska funta" },
            { "lkr", "\u0161rilankanska rupija" },
            { "lrd", "liberijski dolar" },
            { "lsl", "lesoto loti" },
            { "ltl", "litavski litas" },
            { "ltt", "litavski talonas" },
            { "luc", "luksembur\u0161ki konvertibilni franak" },
            { "luf", "luksembur\u0161ki franak" },
            { "lul", "luksembur\u0161ki financijski franak" },
            { "lvl", "letonski lats" },
            { "lvr", "letonska rublja" },
            { "lyd", "libijski dinar" },
            { "mad", "marokanski dirham" },
            { "maf", "marokanski franak" },
            { "mdc", "moldavski kupon" },
            { "mdl", "moldavski lej" },
            { "mga", "malga\u0161ki arijari" },
            { "mgf", "madagaskarski franak" },
            { "mkd", "makedonski denar" },
            { "mkn", "stari makedonski denar" },
            { "mlf", "malijski franak" },
            { "mmk", "mjanmarski kjat" },
            { "mnt", "mongolski tugrik" },
            { "mop", "makao\u0161ka pataka" },
            { "mro", "mauritanijska ouguja (1973. \u2013 2017.)" },
            { "mru", "mauritanijska ouguja" },
            { "mtl", "malte\u0161ka lira" },
            { "mtp", "malte\u0161ka funta" },
            { "mur", "mauricijska rupija" },
            { "mvp", "maldivijska rupija" },
            { "mvr", "maldivijska rufija" },
            { "mwk", "malavijska kva\u010da" },
            { "mxn", "meksi\u010dki pezo" },
            { "mxp", "meksi\u010dki srebrni pezo (1861\u20131992)" },
            { "mxv", "meksi\u010dki unidad de inversion (UDI)" },
            { "myr", "malezijski ringit" },
            { "mze", "mozambijski eskudo" },
            { "mzm", "stari mozambijski metikal" },
            { "mzn", "mozambi\u010dki metikal" },
            { "nad", "namibijski dolar" },
            { "ngn", "nigerijska naira" },
            { "nic", "nikaragvanska kordoba" },
            { "nio", "nikaragvanska zlatna kordoba" },
            { "nlg", "nizozemski gulden" },
            { "nok", "norve\u0161ka kruna" },
            { "npr", "nepalska rupija" },
            { "nzd", "novozelandski dolar" },
            { "omr", "omanski rijal" },
            { "pab", "panamska balboa" },
            { "pei", "peruanski inti" },
            { "pen", "peruanski sol" },
            { "pes", "peruanski sol (1863\u20131965)" },
            { "pgk", "kina Papue Nove Gvineje" },
            { "php", "filipinski pezo" },
            { "pkr", "pakistanska rupija" },
            { "pln", "poljska zlota" },
            { "plz", "poljska zlota (1950.\u20131995.)" },
            { "pte", "portugalski eskudo" },
            { "pyg", "paragvajski gvarani" },
            { "qar", "katarski rial" },
            { "rhd", "rodezijski dolar" },
            { "rol", "starorumunjski lek" },
            { "ron", "rumunjski lej" },
            { "rsd", "srpski dinar" },
            { "rub", "ruski rubalj" },
            { "rur", "ruska rublja (1991.\u20131998.)" },
            { "rwf", "ruandski franak" },
            { "sar", "saudijski rijal" },
            { "sbd", "solmonskooto\u010dni dolar" },
            { "scr", "sej\u0161elska rupija" },
            { "sdd", "sudanski dinar" },
            { "sdg", "sudanska funta" },
            { "sdp", "stara sudanska funta" },
            { "sek", "\u0161vedska kruna" },
            { "sgd", "singapurski dolar" },
            { "shp", "svetohelenska funta" },
            { "sit", "slovenski tolar" },
            { "skk", "slova\u010dka kruna" },
            { "sll", "sijeraleonski leone" },
            { "sos", "somalijski \u0161iling" },
            { "srd", "surinamski dolar" },
            { "srg", "surinamski gulden" },
            { "ssp", "ju\u017enosudanska funta" },
            { "std", "dobra Svetog Tome i Principa (1977\u20132017)" },
            { "stn", "dobra Svetog Tome i Principa" },
            { "sur", "sovjetska rublja" },
            { "svc", "salvadorski kolon" },
            { "syp", "sirijska funta" },
            { "szl", "svazi lilangeni" },
            { "thb", "tajlandski baht" },
            { "tjr", "tajikistanska rublja" },
            { "tjs", "tad\u017eikistanski somoni" },
            { "tmm", "turkmenistanski manat (1993.\u20132009.)" },
            { "tmt", "turkmenistanski manat" },
            { "tnd", "tuniski dinar" },
            { "top", "tonga\u0161ka pa\u2019anga" },
            { "tpe", "timorski eskudo" },
            { "trl", "turska lira (1922.\u20132005.)" },
            { "try", "turska lira" },
            { "ttd", "trininadtoba\u0161ki dolar" },
            { "twd", "novotajvanski dolar" },
            { "tzs", "tanzanijski \u0161iling" },
            { "uah", "ukrajinska hrivnja" },
            { "uak", "ukrajinski karbovanet" },
            { "ugs", "ugandski \u0161iling (1966.\u20131987.)" },
            { "ugx", "ugandski \u0161iling" },
            { "usd", "ameri\u010dki dolar" },
            { "usn", "ameri\u010dki dolar (sljede\u0107i dan)" },
            { "uss", "ameri\u010dki dolar (isti dan)" },
            { "uyi", "urugvajski pezo en unidades indexadas" },
            { "uyp", "urugvajski pezo (1975.\u20131993.)" },
            { "uyu", "urugvajski pezo" },
            { "uzs", "uzbekistanski som" },
            { "veb", "venezuelanski bolivar (1871.\u20132008.)" },
            { "vef", "venezuelanski bolivar (2008. \u2013 2018.)" },
            { "ves", "venezuelanski bolivar" },
            { "vnd", "vijetnamski dong" },
            { "vnn", "vijetnamski dong (1978.\u20131985.)" },
            { "vuv", "vanuatski vatu" },
            { "wst", "samoanska tala" },
            { "xaf", "CFA franak BEAC" },
            { "xag", "srebro" },
            { "xau", "zlato" },
            { "xba", "Europska slo\u017eena jedinica" },
            { "xbb", "Europska monetarna jedinica" },
            { "xbc", "europska obra\u010dunska jedinica (XBC)" },
            { "xbd", "europska obra\u010dunska jedinica (XBD)" },
            { "xcd", "isto\u010dnokaripski dolar" },
            { "xdr", "posebna crta\u0107a prava" },
            { "xeu", "europska monetarna jedinica (ECU)" },
            { "xfo", "francuski zlatni franak" },
            { "xfu", "francuski UIC-franak" },
            { "xof", "CFA franak BCEAO" },
            { "xpd", "paladij" },
            { "xpf", "CFP franak" },
            { "xpt", "platina" },
            { "xre", "RINET fondovi" },
            { "xsu", "sukre" },
            { "xts", "ispitni kod valute" },
            { "xua", "obra\u010dunska jedinica ADB" },
            { "xxx", "nepoznata valuta" },
            { "ydd", "jemenski dinar" },
            { "yer", "jemenski rijal" },
            { "yud", "jugoslavenski \u010dvrsti dinar" },
            { "yum", "jugoslavenski novi dinar" },
            { "yun", "jugoslavenski konvertibilni dinar" },
            { "yur", "jugoslavenski reformirani dinar" },
            { "zal", "ju\u017enoafri\u010dki rand (financijski)" },
            { "zar", "ju\u017enoafri\u010dki rand" },
            { "zmk", "zambijska kva\u010da (1968\u20132012)" },
            { "zmw", "zambijska kva\u010da" },
            { "zrn", "zairski novi zair" },
            { "zrz", "zairski zair" },
            { "zwd", "zimbabveanski dolar (1980.\u20132008.)" },
            { "zwl", "zimbabveanski dolar (2009)" },
            { "zwr", "zimbabveanski dolar (2008)" },
        };
        return data;
    }
}
